package exnihilocreatio.blocks;

import exnihilocreatio.barrel.modes.block.BarrelModeBlock;
import exnihilocreatio.barrel.modes.compost.BarrelModeCompost;
import exnihilocreatio.barrel.modes.fluid.BarrelModeFluid;
import exnihilocreatio.barrel.modes.transform.BarrelModeFluidTransform;
import exnihilocreatio.config.ModConfig;
import exnihilocreatio.tiles.TileBarrel;
import exnihilocreatio.util.Util;
import lombok.Getter;
import mcjty.theoneprobe.api.IProbeHitData;
import mcjty.theoneprobe.api.IProbeInfo;
import mcjty.theoneprobe.api.IProbeInfoAccessor;
import mcjty.theoneprobe.api.ProbeMode;
import net.minecraft.block.Block;
import net.minecraft.block.ITileEntityProvider;
import net.minecraft.block.material.Material;
import net.minecraft.block.state.IBlockState;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.EnumHand;
import net.minecraft.util.math.AxisAlignedBB;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.text.TextFormatting;
import net.minecraft.world.IBlockAccess;
import net.minecraft.world.World;
import org.apache.commons.lang3.StringUtils;

import javax.annotation.Nonnull;
import java.util.ArrayList;
import java.util.List;

public class BlockBarrel extends BlockBase implements ITileEntityProvider, IProbeInfoAccessor {

    private final AxisAlignedBB boundingBox = new AxisAlignedBB(0.0625f, 0, 0.0625f, 0.9375f, 1f, 0.9375f);
    @Getter
    private int tier;

    public BlockBarrel(int tier, Material material) {
        super(material, "block_barrel" + tier);
        this.tier = tier;
        this.func_149711_c(2.0f);
    }

    @SuppressWarnings("deprecation")
    @Override
    public int getLightValue(@Nonnull IBlockState state, IBlockAccess world, @Nonnull BlockPos pos) {
        TileEntity te = world.func_175625_s(pos);

        if (te != null && te instanceof TileBarrel) {
            TileBarrel tile = (TileBarrel) te;
            if (tile.getMode() instanceof BarrelModeBlock) {
                BarrelModeBlock mode = (BarrelModeBlock) tile.getMode();

                if (mode.getBlock() != null) {
                    return Block.func_149634_a(mode.getBlock().getItem()).getStateFromMeta(mode.getBlock().getMeta()).getLightValue();
                }
            } else if (tile.getMode() instanceof BarrelModeFluid) {
                BarrelModeFluid mode = (BarrelModeFluid) tile.getMode();

                if (mode.getFluidHandler(tile).getFluidAmount() > 0) {
                    return Util.getLightValue(mode.getFluidHandler(tile).getFluid());
                }
            } else if (ModConfig.misc.enableBarrelTransformLighting) {
                if (tile.getMode() instanceof BarrelModeCompost) {
                    BarrelModeCompost mode = (BarrelModeCompost) tile.getMode();

                    if (mode.getCompostState() != null) {
                        int value = mode.getCompostState().getLightValue() / 2;

                        return Math.round(Util.weightedAverage((float) value / 2, value, mode.getProgress()));
                    }
                } else if (tile.getMode() instanceof BarrelModeFluidTransform) {
                    BarrelModeFluidTransform mode = (BarrelModeFluidTransform) tile.getMode();

                    int inputValue = Util.getLightValue(mode.getInputStack());
                    int outputValue = Util.getLightValue(mode.getOutputStack());

                    return Math.round(Util.weightedAverage(outputValue, inputValue, mode.getProgress()));
                }
            }
        }

        return super.getLightValue(state, world, pos);
    }

    @Override
    public boolean func_180639_a(World worldIn, BlockPos pos, IBlockState state, EntityPlayer playerIn, EnumHand hand, EnumFacing facing, float hitX, float hitY, float hitZ) {
        if (worldIn.field_72995_K || worldIn.func_175625_s(pos) == null)
            return true;

        return ((TileBarrel) worldIn.func_175625_s(pos)).onBlockActivated(worldIn, pos, state, playerIn, hand, facing, hitX, hitY, hitZ);
    }

    @Override
    @Deprecated
    public boolean func_149730_j(IBlockState state) {
        return false;
    }

    @Override
    @Deprecated
    public boolean func_149662_c(IBlockState state) {
        return false;
    }

    @Override
    public TileEntity func_149915_a(@Nonnull World worldIn, int meta) {
        return new TileBarrel(this);
    }

    @Override
    @Nonnull
    @Deprecated
    public AxisAlignedBB func_185496_a(IBlockState state, IBlockAccess source, BlockPos pos) {
        return boundingBox;
    }

    @Override
    public boolean func_185481_k(IBlockState state) {
        return false;
    }

    @Override
    @Deprecated
    public boolean func_149686_d(IBlockState state) {
        return false;
    }

    @Override
    public void addProbeInfo(ProbeMode mode, IProbeInfo probeInfo, EntityPlayer player, World world,
                             IBlockState blockState, IProbeHitData data) {
        TileBarrel barrel = (TileBarrel) world.func_175625_s(data.getPos());
        if (barrel == null)
            return;

        if (mode == ProbeMode.EXTENDED)
            probeInfo.text(TextFormatting.GREEN + "Mode: " + StringUtils.capitalize(barrel.getMode().getName()));

        List<String> tooltips = barrel.getMode().getWailaTooltip(barrel, new ArrayList<String>());
        for (String tooltip : tooltips) {
            probeInfo.text(tooltip);
        }
    }

}
