package exnihilocreatio.registries.manager;

import exnihilocreatio.ModBlocks;
import exnihilocreatio.ModFluids;
import exnihilocreatio.ModItems;
import exnihilocreatio.blocks.BlockSieve.MeshType;
import exnihilocreatio.items.EnumPebbleSubtype;
import exnihilocreatio.items.ItemPebble;
import exnihilocreatio.items.ItemResource;
import exnihilocreatio.items.ore.ItemOre;
import exnihilocreatio.items.seeds.ItemSeedBase;
import exnihilocreatio.registries.*;
import exnihilocreatio.registries.registries.CompostRegistryNew;
import exnihilocreatio.registries.registries.CrookRegistryNew;
import exnihilocreatio.registries.registries.HammerRegistryNew;
import exnihilocreatio.registries.registries.SieveRegistryNew;
import exnihilocreatio.texturing.Color;
import exnihilocreatio.util.BlockInfo;
import exnihilocreatio.util.ItemInfo;
import exnihilocreatio.util.Util;
import net.minecraft.block.BlockStone;
import net.minecraft.block.state.IBlockState;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;
import net.minecraft.item.ItemStack;
import net.minecraftforge.fluids.FluidRegistry;
import net.minecraftforge.oredict.OreDictionary;

public class ExNihiloDefaultRecipes implements  ICrucibleDefaultRegistryProvider, IFluidBlockDefaultRegistryProvider,
        IFluidTransformDefaultRegistryProvider, IFluidOnTopDefaultRegistryProvider, IHeatDefaultRegistryProvider, IOreDefaultRegistryProvider {

    public static void registerDefaults(){
        ExNihiloRegistryManager.registerSieveDefaultRecipeHandler(new SieveDefaults());
        ExNihiloRegistryManager.registerHammerDefaultRecipeHandler(new HammerDefaults());
        ExNihiloRegistryManager.registerCompostDefaultRecipeHandler(new CompostDefaults());
        ExNihiloRegistryManager.registerCrookDefaultRecipeHandler(new CrookDefaults());

        System.out.println("1:ExNihiloRegistryManager.HAMMER_REGISTRY = " + ExNihiloRegistryManager.HAMMER_REGISTRY);

        // ExNihiloRegistryManager.registerCrucibleDefaultRecipeHandler(this);
        // ExNihiloRegistryManager.registerFluidBlockDefaultRecipeHandler(this);
        // ExNihiloRegistryManager.registerFluidTransformDefaultRecipeHandler(this);
        // ExNihiloRegistryManager.registerFluidOnTopDefaultRecipeHandler(this);
        // ExNihiloRegistryManager.registerHeatDefaultRecipeHandler(this);
        // ExNihiloRegistryManager.registerOreDefaultRecipeHandler(this);

    }

    @Override
    public void registerCrucibleRecipeDefaults() {
        CrucibleRegistryStone.register(new ItemStack(Blocks.field_150347_e), FluidRegistry.LAVA, 250);
    }

    @Override
    public void registerFluidBlockRecipeDefaults() {
        FluidBlockTransformerRegistry.register(FluidRegistry.WATER, new ItemInfo(new ItemStack(ModBlocks.dust)), new ItemInfo(new ItemStack(Blocks.field_150435_aG)));
        FluidBlockTransformerRegistry.register(FluidRegistry.LAVA, new ItemInfo(new ItemStack(Items.field_151137_ax)), new ItemInfo(new ItemStack(Blocks.field_150424_aL)));
        FluidBlockTransformerRegistry.register(FluidRegistry.LAVA, new ItemInfo(new ItemStack(Items.field_151114_aO)), new ItemInfo(new ItemStack(Blocks.field_150377_bs)));
        FluidBlockTransformerRegistry.register(ModFluids.fluidWitchwater, new ItemInfo(new ItemStack(Blocks.field_150354_m)), new ItemInfo(new ItemStack(Blocks.field_150425_aM)));
    }

    @Override
    public void registerFluidTransformRecipeDefaults() {
        FluidTransformRegistry.register("water", "witchwater", 12000, new BlockInfo[]{new BlockInfo(Blocks.field_150391_bh.func_176223_P())}, new BlockInfo[]{new BlockInfo(Blocks.field_150338_P.func_176223_P()), new BlockInfo(Blocks.field_150337_Q.func_176223_P())});
    }

    @Override
    public void registerFluidOnTopRecipeDefaults() {
        FluidOnTopRegistry.register(FluidRegistry.LAVA, FluidRegistry.WATER, new ItemInfo(Blocks.field_150343_Z.func_176223_P()));
        FluidOnTopRegistry.register(FluidRegistry.WATER, FluidRegistry.LAVA, new ItemInfo(Blocks.field_150347_e.func_176223_P()));
    }

    @Override
    public void registerHeatRecipeDefaults() {
        // Vanilla fluids are weird, the "flowing" variant is simply a temporary state of checking if it can flow.
        // So, once the lava has spread out all the way, it will all actually be "still" lava.
        // Thanks Mojang <3
        HeatRegistry.register(new BlockInfo(Blocks.field_150356_k, -1), 3);
        HeatRegistry.register(new BlockInfo(Blocks.field_150353_l, -1), 3);
        HeatRegistry.register(new BlockInfo(Blocks.field_150480_ab, -1), 4);
        HeatRegistry.register(new BlockInfo(Blocks.field_150478_aa, -1), 1);

    }

    @SuppressWarnings("deprecation")
    @Override
    public void registerOreRecipeDefaults() {
        OreRegistry.register("gold", new Color("FFFF00"), new ItemInfo(Items.field_151043_k, 0));
        OreRegistry.register("iron", new Color("BF8040"), new ItemInfo(Items.field_151042_j, 0));

        //TODO: Better way, will most likely never grab as it is just called before many mods init their oredict
        if (OreDictionary.getOres("oreCopper").size() > 0) {
            OreRegistry.register("copper", new Color("FF9933"), null);
        }

        if (OreDictionary.getOres("oreTin").size() > 0) {
            OreRegistry.register("tin", new Color("E6FFF2"), null);
        }

        if (OreDictionary.getOres("oreAluminium").size() > 0 || OreDictionary.getOres("oreAluminum").size() > 0) {
            OreRegistry.register("aluminium", new Color("BFBFBF"), null);
        }

        if (OreDictionary.getOres("oreLead").size() > 0) {
            OreRegistry.register("lead", new Color("330066"), null);
        }

        if (OreDictionary.getOres("oreSilver").size() > 0) {
            OreRegistry.register("silver", new Color("F2F2F2"), null);
        }

        if (OreDictionary.getOres("oreNickel").size() > 0) {
            OreRegistry.register("nickel", new Color("FFFFCC"), null);
        }

        if (OreDictionary.getOres("oreArdite").size() > 0) {
            OreRegistry.register("ardite", new Color("FF751A"), null);
        }

        if (OreDictionary.getOres("oreCobalt").size() > 0) {
            OreRegistry.register("cobalt", new Color("3333FF"), null);
        }

    }

    private static class CompostDefaults implements ICompostDefaultRegistryProvider {
        @Override
        public void registerRecipeDefaults(CompostRegistryNew registry) {
            IBlockState dirtState = Blocks.field_150346_d.func_176223_P();

            registry.register(Items.field_151078_bh, 0, 0.1f, dirtState, new Color("C45631"));

            registry.register(Blocks.field_150345_g, 0, 0.125f, dirtState, new Color("35A82A"));
            registry.register(Blocks.field_150345_g, 1, 0.125f, dirtState, new Color("2E8042"));
            registry.register(Blocks.field_150345_g, 2, 0.125f, dirtState, new Color("6CC449"));
            registry.register(Blocks.field_150345_g, 3, 0.125f, dirtState, new Color("22A116"));
            registry.register(Blocks.field_150345_g, 4, 0.125f, dirtState, new Color("B8C754"));
            registry.register(Blocks.field_150345_g, 5, 0.125f, dirtState, new Color("378030"));

            registry.register(Blocks.field_150362_t, 0, 0.125f, dirtState, new Color("35A82A"));
            registry.register(Blocks.field_150362_t, 1, 0.125f, dirtState, new Color("2E8042"));
            registry.register(Blocks.field_150362_t, 2, 0.125f, dirtState, new Color("6CC449"));
            registry.register(Blocks.field_150362_t, 3, 0.125f, dirtState, new Color("22A116"));
            registry.register(Blocks.field_150361_u, 0, 0.125f, dirtState, new Color("B8C754"));
            registry.register(Blocks.field_150361_u, 1, 0.125f, dirtState, new Color("378030"));

            registry.register(Items.field_151070_bp, 0, 0.08f, dirtState, new Color("963E44"));

            registry.register(Items.field_151015_O, 0, 0.08f, dirtState, new Color("E3E162"));
            registry.register(Items.field_151014_N, 0, 0.08f, dirtState, new Color("35A82A"));
            registry.register(Items.field_151025_P, 0, 0.16f, dirtState, new Color("D1AF60"));

            registry.register(Blocks.field_150327_N, 0, 0.10f, dirtState, new Color("FFF461"));
            registry.register(Blocks.field_150328_O, 0, 0.10f, dirtState, new Color("FF1212"));
            registry.register(Blocks.field_150328_O, 1, 0.10f, dirtState, new Color("33CFFF"));
            registry.register(Blocks.field_150328_O, 2, 0.10f, dirtState, new Color("F59DFA"));
            registry.register(Blocks.field_150328_O, 3, 0.10f, dirtState, new Color("E3E3E3"));
            registry.register(Blocks.field_150328_O, 4, 0.10f, dirtState, new Color("FF3D12"));
            registry.register(Blocks.field_150328_O, 5, 0.10f, dirtState, new Color("FF7E29"));
            registry.register(Blocks.field_150328_O, 6, 0.10f, dirtState, new Color("FFFFFF"));
            registry.register(Blocks.field_150328_O, 7, 0.10f, dirtState, new Color("F5C4FF"));
            registry.register(Blocks.field_150328_O, 8, 0.10f, dirtState, new Color("E9E9E9"));

            registry.register(Blocks.field_150398_cm, 0, 0.10f, dirtState, new Color("FFDD00"));
            registry.register(Blocks.field_150398_cm, 1, 0.10f, dirtState, new Color("FCC7F0"));
            registry.register(Blocks.field_150398_cm, 4, 0.10f, dirtState, new Color("FF1212"));
            registry.register(Blocks.field_150398_cm, 5, 0.10f, dirtState, new Color("F3D2FC"));

            registry.register(Blocks.field_150338_P, 0, 0.10f, dirtState, new Color("CFBFB6"));
            registry.register(Blocks.field_150337_Q, 0, 0.10f, dirtState, new Color("D6A8A5"));

            registry.register(Items.field_151158_bO, 0, 0.16f, dirtState, new Color("E39A6D"));

            registry.register(Items.field_151147_al, 0, 0.2f, dirtState, new Color("FFA091"));
            registry.register(Items.field_151157_am, 0, 0.2f, dirtState, new Color("FFFDBD"));

            registry.register(Items.field_151082_bd, 0, 0.2f, dirtState, new Color("FF4242"));
            registry.register(Items.field_151083_be, 0, 0.2f, dirtState, new Color("80543D"));

            registry.register(Items.field_151076_bf, 0, 0.2f, dirtState, new Color("FFE8E8"));
            registry.register(Items.field_151077_bg, 0, 0.2f, dirtState, new Color("FA955F"));

            registry.register(Items.field_151115_aP, 0, 0.15f, dirtState, new Color("6DCFB3"));
            registry.register(Items.field_179566_aV, 0, 0.15f, dirtState, new Color("D8EBE5"));

            registry.register(Items.field_151115_aP, 1, 0.15f, dirtState, new Color("FF2E4A"));
            registry.register(Items.field_179566_aV, 1, 0.15f, dirtState, new Color("E87A3F"));

            registry.register(Items.field_151115_aP, 2, 0.15f, dirtState, new Color("FF771C"));
            registry.register(Items.field_151115_aP, 3, 0.15f, dirtState, new Color("DBFAFF"));

            registry.register(ModItems.resources, ItemResource.getMetaFromName(ItemResource.SILKWORM), 0.04f, dirtState, new Color("ff9966"));
            registry.register(ModItems.cookedSilkworm, 0, 0.04f, dirtState, new Color("cc6600"));

            registry.register(Items.field_151034_e, 0, 0.10f, dirtState, new Color("FFF68F"));
            registry.register(Items.field_151127_ba, 0, 0.04f, dirtState, new Color("FF443B"));
            registry.register(Blocks.field_150440_ba, 0, 1.0f / 6, dirtState, new Color("FF443B"));
            registry.register(Blocks.field_150423_aK, 0, 1.0f / 6, dirtState, new Color("FFDB66"));
            registry.register(Blocks.field_150428_aP, 0, 1.0f / 6, dirtState, new Color("FFDB66"));

            registry.register(Blocks.field_150434_aF, 0, 0.10f, dirtState, new Color("DEFFB5"));

            registry.register(Items.field_151172_bF, 0, 0.08f, dirtState, new Color("FF9B0F"));
            registry.register(Items.field_151174_bG, 0, 0.08f, dirtState, new Color("FFF1B5"));
            registry.register(Items.field_151168_bH, 0, 0.08f, dirtState, new Color("FFF1B5"));
            registry.register(Items.field_151170_bI, 0, 0.08f, dirtState, new Color("E0FF8A"));

            registry.register(Blocks.field_150392_bi, 0, 0.10f, dirtState, new Color("269900"));
            registry.register(Blocks.field_150395_bd, 0, 0.10f, dirtState, new Color("23630E"));
            registry.register(Blocks.field_150329_H, 1, 0.08f, dirtState, new Color("23630E"));
            registry.register(Items.field_151110_aK, 0, 0.08f, dirtState, new Color("FFFA66"));
            registry.register(Items.field_151075_bm, 0, 0.10f, dirtState, new Color("FF2B52"));
            registry.register(Items.field_151120_aE, 0, 0.08f, dirtState, new Color("9BFF8A"));
            registry.register(Items.field_151007_F, 0, 0.04f, dirtState, Util.whiteColor);
        }
    }

    private static class CrookDefaults implements ICrookDefaultRegistryProvider {
        @Override
        public void registerRecipeDefaults(CrookRegistryNew registry) {
            registry.register(new BlockInfo(Blocks.field_150362_t, -1), ItemResource.getResourceStack(ItemResource.SILKWORM), 0.1f, 0f);
            registry.register(new BlockInfo(Blocks.field_150361_u, -1), ItemResource.getResourceStack(ItemResource.SILKWORM), 0.1f, 0f);
        }
    }

    private static class SieveDefaults implements ISieveDefaultRegistryProvider {
        @Override
        public void registerRecipeDefaults(SieveRegistryNew registry) {
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("stone"), 1f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("stone"), 1f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("stone"), 0.5f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("stone"), 0.5f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("stone"), 0.1f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("stone"), 0.1f, MeshType.STRING.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("granite"), 0.5f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("granite"), 0.1f, MeshType.STRING.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("diorite"), 0.5f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("diorite"), 0.1f, MeshType.STRING.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("andesite"), 0.5f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemPebble.getPebbleStack("andesite"), 0.1f, MeshType.STRING.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), new ItemInfo(Items.field_151014_N, 0), 0.7f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), new ItemInfo(Items.field_151081_bc, 0), 0.35f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), new ItemInfo(Items.field_151080_bb, 0), 0.35f, MeshType.STRING.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150354_m.func_176223_P(), new ItemInfo(Items.field_151100_aR, 3), 0.03f, MeshType.STRING.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemInfo(Items.field_151145_ak, 0), 0.25f, MeshType.FLINT.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemInfo(Items.field_151044_h, 0), 0.125f, MeshType.FLINT.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemInfo(Items.field_151100_aR, 4), 0.05f, MeshType.FLINT.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemInfo(Items.field_151045_i, 0), 0.008f, MeshType.IRON.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemInfo(Items.field_151166_bC, 0), 0.008f, MeshType.IRON.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemInfo(Items.field_151045_i, 0), 0.016f, MeshType.DIAMOND.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemInfo(Items.field_151166_bC, 0), 0.016f, MeshType.DIAMOND.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150425_aM.func_176223_P(), new ItemInfo(Items.field_151128_bU, 0), 1f, MeshType.FLINT.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150425_aM.func_176223_P(), new ItemInfo(Items.field_151128_bU, 0), 0.33f, MeshType.FLINT.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150425_aM.func_176223_P(), new ItemInfo(Items.field_151075_bm, 0), 0.1f, MeshType.STRING.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150425_aM.func_176223_P(), new ItemInfo(Items.field_151073_bk, 0), 0.02f, MeshType.DIAMOND.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150425_aM.func_176223_P(), new ItemInfo(Items.field_151128_bU, 0), 1f, MeshType.DIAMOND.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150425_aM.func_176223_P(), new ItemInfo(Items.field_151128_bU, 0), 0.8f, MeshType.DIAMOND.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(ModBlocks.dust.func_176223_P(), new ItemInfo(Items.field_151100_aR, 15), 0.2f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(ModBlocks.dust.func_176223_P(), new ItemInfo(Items.field_151016_H, 0), 0.07f, MeshType.STRING.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(ModBlocks.dust.func_176223_P(), new ItemInfo(Items.field_151137_ax, 0), 0.125f, MeshType.IRON.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(ModBlocks.dust.func_176223_P(), new ItemInfo(Items.field_151137_ax, 0), 0.25f, MeshType.DIAMOND.getID());

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(ModBlocks.dust.func_176223_P(), new ItemInfo(Items.field_151114_aO, 0), 0.0625f, MeshType.IRON.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(ModBlocks.dust.func_176223_P(), new ItemInfo(Items.field_151065_br, 0), 0.05f, MeshType.IRON.getID());

            // SieveRegistry.register(ModBlocks.netherrackCrushed.getDefaultState(), new ItemInfo(Items.BLAZE_POWDER, 0), 0.05f, MeshType.IRON.getID());
            // TODO: add tinkers ardite to sieve and add ores for it

            // Ores
            for (ItemOre ore : OreRegistry.getItemOreRegistry()) {
                ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemStack(ore, 1, 0), 0.2f, MeshType.FLINT.getID());
                ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemStack(ore, 1, 0), 0.2f, MeshType.IRON.getID());
                ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150351_n.func_176223_P(), new ItemStack(ore, 1, 0), 0.1f, MeshType.DIAMOND.getID());
            }

            // Seeds
            for (ItemSeedBase seed : ModItems.itemSeeds) {
                ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), new ItemStack(seed), 0.05f, MeshType.STRING.getID());
            }

            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemResource.getResourceStack(ItemResource.ANCIENT_SPORES), 0.05f, MeshType.STRING.getID());
            ExNihiloRegistryManager.SIEVE_REGISTRY.register(Blocks.field_150346_d.func_176223_P(), ItemResource.getResourceStack(ItemResource.GRASS_SEEDS), 0.05f, MeshType.STRING.getID());
        }
    }

    private static class HammerDefaults implements IHammerDefaultRegistryProvider {
        @Override
        public void registerRecipeDefaults(HammerRegistryNew registry) {
            registry.register(Blocks.field_150347_e.func_176223_P(), new ItemStack(Blocks.field_150351_n, 1), 0, 1.0F, 0.0F);
            registry.register(Blocks.field_150351_n.func_176223_P(), new ItemStack(Blocks.field_150354_m, 1), 0, 1.0F, 0.0F);
            registry.register(Blocks.field_150354_m.func_176223_P(), new ItemStack(ModBlocks.dust, 1), 0, 1.0F, 0.0F);
            registry.register(Blocks.field_150424_aL.func_176223_P(), new ItemStack(ModBlocks.netherrackCrushed, 1), 0, 1.0F, 0.0F);
            registry.register(Blocks.field_150377_bs.func_176223_P(), new ItemStack(ModBlocks.endstoneCrushed, 1), 0, 1.0F, 0.0F);

            // Hammering Logs gives planks
            registry.register(Blocks.field_150364_r.func_176223_P(), new ItemStack(Blocks.field_150344_f), 0, 1.0F, 0.0F, true);

            // Hammering stone into pebbles (no idea why anyone should do that, but hey :P)
            registry.register(Blocks.field_150348_b.func_176223_P().func_177226_a(BlockStone.field_176247_a, BlockStone.EnumType.STONE), new ItemStack(ModItems.pebbles, 1, EnumPebbleSubtype.STONE.getMeta()), 1, 3F, 1.25F);
            registry.register(Blocks.field_150348_b.func_176223_P().func_177226_a(BlockStone.field_176247_a, BlockStone.EnumType.ANDESITE), new ItemStack(ModItems.pebbles, 1, EnumPebbleSubtype.ANDESITE.getMeta()), 1, 3F, 1.25F);
            registry.register(Blocks.field_150348_b.func_176223_P().func_177226_a(BlockStone.field_176247_a, BlockStone.EnumType.GRANITE), new ItemStack(ModItems.pebbles, 1, EnumPebbleSubtype.GRANITE.getMeta()), 1, 3F, 1.25F);
            registry.register(Blocks.field_150348_b.func_176223_P().func_177226_a(BlockStone.field_176247_a, BlockStone.EnumType.DIORITE), new ItemStack(ModItems.pebbles, 1, EnumPebbleSubtype.DIORITE.getMeta()), 1, 3F, 1.25F);
        }
    }
}
